# Release History

## 1.0.0b2 (2024-03-04)

### Features Added

  - Model Account has a new parameter properties
  - Model AccountUpdate has a new parameter properties
  - Model Quota has a new parameter properties

### Breaking Changes

  - Model Account no longer has parameter dashboard_uri
  - Model Account no longer has parameter provisioning_state
  - Model Account no longer has parameter regional_affinity
  - Model Account no longer has parameter reporting
  - Model Account no longer has parameter scalable_execution
  - Model AccountUpdate no longer has parameter regional_affinity
  - Model AccountUpdate no longer has parameter reporting
  - Model AccountUpdate no longer has parameter scalable_execution
  - Model Quota no longer has parameter free_trial
  - Model Quota no longer has parameter provisioning_state

## 1.0.0b1 (2023-09-27)

* Initial Release
